{% extends "base.html" %}
{% block title %}Index{% endblock %}
{% block content %}
    {% for database in databases %}
        <h2>{{ database.title }}</h2>
        <ul>
            {% for script in database.scripts %}
                <li><a href="{{ script.path }}">{{ script.title }}</a></li>
            {% endfor %}
        </ul>
    {% endfor %}
{% endblock %}