@import url('https://fonts.googleapis.com/css2?family=Roboto+Mono:ital,wght@0,400;0,700;1,400&family=Roboto:ital,wght@0,400;0,700;1,300&display=swap');

body {
    background-color: {{ screen.background }};
    color: {{ screen.color }};
    scroll-behavior: smooth;
}

#content {
    font-size: {{ font.size }}px;
    padding: {{ screen.padding.horizontal }}px {{ screen.padding.vertical }}px;
    font-family: {{ font.family}};
}

h1, h2, h3, h4, h5 {
    margin: {{ screen.hmargin.vertical }}px {{ screen.hmargin.horizontal }}px;
}

p {
    margin: {{ screen.pmargin.vertical }}px {{ screen.pmargin.horizontal }}px;
}

a {
    text-decoration: underline;
    color: {{ screen.color }};
}

.mirrored {
    -moz-transform: scale(-1, 1);
    -webkit-transform: scale(-1, 1);
    -o-transform: scale(-1, 1);
    -ms-transform: scale(-1, 1);
    transform: scale(-1, 1);
}

#help {
    list-style: none;
    font-size: 2em;
}

kbd {
    color: #fff;
    font-family: monospace;
    text-align: center;
    display: inline;
    font-weight: bold;
    text-transform: lowercase;
}

/* Modal */
.modal {
    position: fixed;
    width: 100vw;
    height: 100vh;
    opacity: 0;
    visibility: hidden;
    transition: all 0.3s ease;
    font-family: 'Roboto', sans-serif;
    top: 0;
    left: 0;
    display: flex;
    align-items: center;
    justify-content: center;
}

.modal.open {
    visibility: visible;
    opacity: 1;
    transition-delay: 0s;
}

.modal-bg {
    position: absolute;
    background: black;
    opacity: 0.5;
    width: 100%;
    height: 100%;
}

.modal-container {
    border-radius: 10px;
    background: #000;
    position: relative;
    padding: 30px;
}

.modal-close {
    position: absolute;
    right: 15px;
    top: 15px;
    outline: none;
    appearance: none;
    color: red;
    background: none;
    border: 0px;
    font-weight: bold;
    cursor: pointer;
}

/* spans */

span.code {
    font-family: 'Roboto Mono', monospace;
    background-color: #ffffff22;
    border-radius: 10px;
    padding: 0 10px;
}

/* Notion coloured blocks */

.notion-black {
	color: rgb(0, 0, 0);
}

.notion-black_background {
	background-color: rgb(0, 0, 0, 0.7);
}

.notion-gray {
	color: rgb(128, 128, 128);
}

.notion-gray_background {
	background-color: rgb(128, 128, 128, 0.7);
}

.notion-brown {
	color: rgb(165, 42, 42);
}

.notion-brown_background {
	background-color: rgb(165, 42, 42, 0.7);
}

.notion-orange {
	color: rgb(255, 165, 0);
}

.notion-orange_background {
	background-color: rgb(255, 165, 0, 0.7);
}

.notion-yellow {
	color: rgb(255, 255, 0);
}

.notion-yellow_background {
	background-color: rgb(255, 255, 0, 0.7);
}

.notion-green {
	color: rgb(0, 128, 0);
}

.notion-green_background {
	background-color: rgb(0, 128, 0, 0.7);
}

.notion-blue {
	color: rgb(0, 0, 255);
}

.notion-blue_background {
	background-color: rgb(0, 0, 255, 0.7);
}

.notion-purple {
	color: rgb(128, 0, 128);
}

.notion-purple_background {
	background-color: rgb(128, 0, 128, 0.7);
}

.notion-pink {
	color: rgb(255, 192, 203);
}

.notion-pink_background {
	background-color: rgb(255, 192, 203, 0.7);
}

.notion-red {
	color: rgb(255, 0, 0);
}

.notion-red_background {
	background-color: rgb(255, 0, 0, 0.7);
}
